Pipeline
A chain of processing steps.
Usage
Pipeline()Each step uses an Engine instance. Configure with Config.
See .run_pipeline for a shortcut to running the full pipeline.
Parameters
steps: list = None-
List of engine names.
A chain of processing steps.
Usage
Each step uses an Engine instance. Configure with Config.
See .run_pipeline for a shortcut to running the full pipeline.
steps: list = NoneList of engine names.